==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QWidgetAction_shell.h <==
#ifndef QWIDGETACTION_SHELL_H
#define QWIDGETACTION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qwidgetaction.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QWidgetAction_shell : public QWidgetAction, public QtJambiShellInterface
{
public:
    QWidgetAction_shell(QObject* parent0);
    ~QWidgetAction_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createWidget(QWidget* parent0) override;
    void customEvent(QEvent* event0) override;
    void deleteWidget(QWidget* widget0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWidgetAction_access : public QWidgetAction
{
    jobject __qt_createdWidgets(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    void __qt_deleteWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QWIDGETACTION_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QWidgetAction_shell.h <==
#ifndef QWIDGETACTION_SHELL_H
#define QWIDGETACTION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qwidgetaction.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicswidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QWidgetAction_shell : public QWidgetAction, public QtJambiShellInterface
{
public:
    QWidgetAction_shell(QObject* parent0);
    ~QWidgetAction_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createWidget(QWidget* parent0) override;
    void customEvent(QEvent* event0) override;
    void deleteWidget(QWidget* widget0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWidgetAction_access : public QWidgetAction
{
    jobject __qt_createdWidgets_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    void __qt_deleteWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jboolean __qt_eventFilter_QObject_ptr_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QWIDGETACTION_SHELL_H
